==> jc-1.4.0.tar.gz: gnu/java/net/protocol/ftp/BlockOutputStream.h <==
// class gnu.java.net.protocol.ftp.BlockOutputStream

// class file dependencies
// @dep_class 6af639705658449f gnu_java_net_protocol_ftp_BlockOutputStream
// @dep_class 8f86c2f0d8bbeb13 gnu_java_net_protocol_ftp_DTPOutputStream
// @dep_class fddb41323d9c4cee java_io_FilterOutputStream
// @dep_class 4026d3144d6654d8 java_io_OutputStream
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_java_net_protocol_ftp_DTPOutputStream

#include "gnu/java/net/protocol/ftp/DTPOutputStream.h"

#ifndef _JC_gnu_java_net_protocol_ftp_BlockOutputStream_H_
#define _JC_gnu_java_net_protocol_ftp_BlockOutputStream_H_

// Forward structure declarations
struct _jc_gnu_java_net_protocol_ftp_DTP$object;
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_ftp_BlockOutputStream$sub_refs	_jc_gnu_java_net_protocol_ftp_BlockOutputStream$sub_refs;
typedef struct _jc_gnu_java_net_protocol_ftp_BlockOutputStream$sub_nonrefs	_jc_gnu_java_net_protocol_ftp_BlockOutputStream$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_ftp_BlockOutputStream$refs	_jc_gnu_java_net_protocol_ftp_BlockOutputStream$refs;
typedef struct _jc_gnu_java_net_protocol_ftp_BlockOutputStream$nonrefs	_jc_gnu_java_net_protocol_ftp_BlockOutputStream$nonrefs;
typedef struct _jc_gnu_java_net_protocol_ftp_BlockOutputStream$object	_jc_gnu_java_net_protocol_ftp_BlockOutputStream$object;

typedef struct _jc_gnu_java_net_protocol_ftp_BlockOutputStream$fields_struct	_jc_gnu_java_net_protocol_ftp_BlockOutputStream$fields_struct;
typedef const struct _jc_gnu_java_net_protocol_ftp_BlockOutputStream$vmethods	_jc_gnu_java_net_protocol_ftp_BlockOutputStream$vmethods;
typedef const struct _jc_gnu_java_net_protocol_ftp_BlockOutputStream$vtable	_jc_gnu_java_net_protocol_ftp_BlockOutputStream$vtable;
typedef const struct _jc_gnu_java_net_protocol_ftp_BlockOutputStream$vtype	_jc_gnu_java_net_protocol_ftp_BlockOutputStream$vtype;

// Class fields structure
struct _jc_gnu_java_net_protocol_ftp_BlockOutputStream$fields_struct {
	jbyte	EOF;
	jbyte	RECORD;
};
extern _jc_gnu_java_net_protocol_ftp_BlockOutputStream$fields_struct _jc_gnu_java_net_protocol_ftp_BlockOutputStream$class_fields;

// Constructors
extern void _jc_gnu_java_net_protocol_ftp_BlockOutputStream$method$_init$6e5b27297a1ccb9b(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_BlockOutputStream$object *, struct _jc_object *, struct _jc_java_io_OutputStream$object *);

// Virtual methods
extern void _jc_gnu_java_net_protocol_ftp_BlockOutputStream$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_BlockOutputStream$object *);
extern void _jc_gnu_java_net_protocol_ftp_BlockOutputStream$method$write$6377ac6964854eb2(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_BlockOutputStream$object *, jint);
extern void _jc_gnu_java_net_protocol_ftp_BlockOutputStream$method$write$18e189e8fc25f121(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_BlockOutputStream$object *, struct _jc_byte_array *);
extern void _jc_gnu_java_net_protocol_ftp_BlockOutputStream$method$write$306a698343ec27e8(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_BlockOutputStream$object *, struct _jc_byte_array *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_protocol_ftp_BlockOutputStream$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_gnu_java_net_protocol_ftp_BlockOutputStream$method_info$write$6377ac6964854eb2;
extern _jc_method _jc_gnu_java_net_protocol_ftp_BlockOutputStream$method_info$write$18e189e8fc25f121;
extern _jc_method _jc_gnu_java_net_protocol_ftp_BlockOutputStream$method_info$write$306a698343ec27e8;

// Virtual methods structure
struct _jc_gnu_java_net_protocol_ftp_BlockOutputStream$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_BlockOutputStream$object *);
	void	(*write$6377ac6964854eb2)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_BlockOutputStream$object *, jint);
	void	(*write$18e189e8fc25f121)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_BlockOutputStream$object *, struct _jc_byte_array *);
	void	(*write$306a698343ec27e8)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_BlockOutputStream$object *, struct _jc_byte_array *, jint, jint);
};

// Vtable
struct _jc_gnu_java_net_protocol_ftp_BlockOutputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_OutputStream$vmethods	java_io_OutputStream;
	_jc_java_io_FilterOutputStream$vmethods	java_io_FilterOutputStream;
	_jc_gnu_java_net_protocol_ftp_DTPOutputStream$vmethods	gnu_java_net_protocol_ftp_DTPOutputStream;
	_jc_gnu_java_net_protocol_ftp_BlockOutputStream$vmethods	gnu_java_net_protocol_ftp_BlockOutputStream;
};

// Vtype
struct _jc_gnu_java_net_protocol_ftp_BlockOutputStream$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_ftp_BlockOutputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_ftp_BlockOutputStream$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_ftp_BlockOutputStream$refs {
    _jc_gnu_java_net_protocol_ftp_BlockOutputStream$sub_refs	gnu_java_net_protocol_ftp_BlockOutputStream;
    _jc_gnu_java_net_protocol_ftp_DTPOutputStream$sub_refs	gnu_java_net_protocol_ftp_DTPOutputStream;
    _jc_java_io_FilterOutputStream$sub_refs	java_io_FilterOutputStream;
    _jc_java_io_OutputStream$sub_refs	java_io_OutputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_ftp_BlockOutputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_ftp_BlockOutputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_OutputStream$sub_nonrefs	java_io_OutputStream;
    _jc_java_io_FilterOutputStream$sub_nonrefs	java_io_FilterOutputStream;
    _jc_gnu_java_net_protocol_ftp_DTPOutputStream$sub_nonrefs	gnu_java_net_protocol_ftp_DTPOutputStream;
    _jc_gnu_java_net_protocol_ftp_BlockOutputStream$sub_nonrefs	gnu_java_net_protocol_ftp_BlockOutputStream;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_ftp_BlockOutputStream$object {
	_jc_gnu_java_net_protocol_ftp_BlockOutputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_ftp_BlockOutputStream$vtype	*vtype;
	_jc_gnu_java_net_protocol_ftp_BlockOutputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_ftp_BlockOutputStream$vtype _jc_gnu_java_net_protocol_ftp_BlockOutputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_ftp_BlockOutputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_ftp_BlockOutputStream$class_object;

#endif	/* _JC_gnu_java_net_protocol_ftp_BlockOutputStream_H_ */

==> jc-1.4.6.tar.gz: gnu/java/net/protocol/ftp/BlockOutputStream.h <==
// class gnu.java.net.protocol.ftp.BlockOutputStream

// class file dependencies
// @dep_class 6af639705658449f gnu_java_net_protocol_ftp_BlockOutputStream
// @dep_class 8f86c2f0d8bbeb13 gnu_java_net_protocol_ftp_DTPOutputStream
// @dep_class fddb41323d9c4cee java_io_FilterOutputStream
// @dep_class 4026d3144d6654d8 java_io_OutputStream
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_java_net_protocol_ftp_DTPOutputStream

#include "gnu/java/net/protocol/ftp/DTPOutputStream.h"

#ifndef _JC_gnu_java_net_protocol_ftp_BlockOutputStream_H_
#define _JC_gnu_java_net_protocol_ftp_BlockOutputStream_H_

// Forward structure declarations
struct _jc_gnu_java_net_protocol_ftp_DTP$object;
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_ftp_BlockOutputStream$sub_refs	_jc_gnu_java_net_protocol_ftp_BlockOutputStream$sub_refs;
typedef struct _jc_gnu_java_net_protocol_ftp_BlockOutputStream$sub_nonrefs	_jc_gnu_java_net_protocol_ftp_BlockOutputStream$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_ftp_BlockOutputStream$refs	_jc_gnu_java_net_protocol_ftp_BlockOutputStream$refs;
typedef struct _jc_gnu_java_net_protocol_ftp_BlockOutputStream$nonrefs	_jc_gnu_java_net_protocol_ftp_BlockOutputStream$nonrefs;
typedef struct _jc_gnu_java_net_protocol_ftp_BlockOutputStream$object	_jc_gnu_java_net_protocol_ftp_BlockOutputStream$object;

typedef struct _jc_gnu_java_net_protocol_ftp_BlockOutputStream$fields_struct	_jc_gnu_java_net_protocol_ftp_BlockOutputStream$fields_struct;
typedef const struct _jc_gnu_java_net_protocol_ftp_BlockOutputStream$vmethods	_jc_gnu_java_net_protocol_ftp_BlockOutputStream$vmethods;
typedef const struct _jc_gnu_java_net_protocol_ftp_BlockOutputStream$vtable	_jc_gnu_java_net_protocol_ftp_BlockOutputStream$vtable;
typedef const struct _jc_gnu_java_net_protocol_ftp_BlockOutputStream$vtype	_jc_gnu_java_net_protocol_ftp_BlockOutputStream$vtype;

// Class fields structure
struct _jc_gnu_java_net_protocol_ftp_BlockOutputStream$fields_struct {
	jbyte	EOF;
	jbyte	RECORD;
};
extern _jc_gnu_java_net_protocol_ftp_BlockOutputStream$fields_struct _jc_gnu_java_net_protocol_ftp_BlockOutputStream$class_fields;

// Constructors
extern void _jc_gnu_java_net_protocol_ftp_BlockOutputStream$method$_init$6e5b27297a1ccb9b(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_BlockOutputStream$object *, struct _jc_object *, struct _jc_java_io_OutputStream$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_net_protocol_ftp_BlockOutputStream$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_BlockOutputStream$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_net_protocol_ftp_BlockOutputStream$method$write$6377ac6964854eb2(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_BlockOutputStream$object *, jint) _JC_JCNI_ATTR;
extern void _jc_gnu_java_net_protocol_ftp_BlockOutputStream$method$write$18e189e8fc25f121(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_BlockOutputStream$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_net_protocol_ftp_BlockOutputStream$method$write$306a698343ec27e8(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_BlockOutputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_protocol_ftp_BlockOutputStream$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_gnu_java_net_protocol_ftp_BlockOutputStream$method_info$write$6377ac6964854eb2;
extern _jc_method _jc_gnu_java_net_protocol_ftp_BlockOutputStream$method_info$write$18e189e8fc25f121;
extern _jc_method _jc_gnu_java_net_protocol_ftp_BlockOutputStream$method_info$write$306a698343ec27e8;

// Virtual methods structure
struct _jc_gnu_java_net_protocol_ftp_BlockOutputStream$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_BlockOutputStream$object *) _JC_JCNI_ATTR;
	void	(*write$6377ac6964854eb2)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_BlockOutputStream$object *, jint) _JC_JCNI_ATTR;
	void	(*write$18e189e8fc25f121)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_BlockOutputStream$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
	void	(*write$306a698343ec27e8)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_BlockOutputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_net_protocol_ftp_BlockOutputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_OutputStream$vmethods	java_io_OutputStream;
	_jc_java_io_FilterOutputStream$vmethods	java_io_FilterOutputStream;
	_jc_gnu_java_net_protocol_ftp_DTPOutputStream$vmethods	gnu_java_net_protocol_ftp_DTPOutputStream;
	_jc_gnu_java_net_protocol_ftp_BlockOutputStream$vmethods	gnu_java_net_protocol_ftp_BlockOutputStream;
};

// Vtype
struct _jc_gnu_java_net_protocol_ftp_BlockOutputStream$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_ftp_BlockOutputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_ftp_BlockOutputStream$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_ftp_BlockOutputStream$refs {
    _jc_gnu_java_net_protocol_ftp_BlockOutputStream$sub_refs	gnu_java_net_protocol_ftp_BlockOutputStream;
    _jc_gnu_java_net_protocol_ftp_DTPOutputStream$sub_refs	gnu_java_net_protocol_ftp_DTPOutputStream;
    _jc_java_io_FilterOutputStream$sub_refs	java_io_FilterOutputStream;
    _jc_java_io_OutputStream$sub_refs	java_io_OutputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_ftp_BlockOutputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_ftp_BlockOutputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_OutputStream$sub_nonrefs	java_io_OutputStream;
    _jc_java_io_FilterOutputStream$sub_nonrefs	java_io_FilterOutputStream;
    _jc_gnu_java_net_protocol_ftp_DTPOutputStream$sub_nonrefs	gnu_java_net_protocol_ftp_DTPOutputStream;
    _jc_gnu_java_net_protocol_ftp_BlockOutputStream$sub_nonrefs	gnu_java_net_protocol_ftp_BlockOutputStream;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_ftp_BlockOutputStream$object {
	_jc_gnu_java_net_protocol_ftp_BlockOutputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_ftp_BlockOutputStream$vtype	*vtype;
	_jc_gnu_java_net_protocol_ftp_BlockOutputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_ftp_BlockOutputStream$vtype _jc_gnu_java_net_protocol_ftp_BlockOutputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_ftp_BlockOutputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_ftp_BlockOutputStream$class_object;

#endif	/* _JC_gnu_java_net_protocol_ftp_BlockOutputStream_H_ */
